# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/localization_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/localization_status.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/localization/proto/localization_status.proto\x12\x13\x61pollo.localization\"\xdc\x01\n\x12MsfSensorMsgStatus\x12@\n\x10imu_delay_status\x18\x01 \x01(\x0e\x32&.apollo.localization.ImuMsgDelayStatus\x12\x44\n\x12imu_missing_status\x18\x02 \x01(\x0e\x32(.apollo.localization.ImuMsgMissingStatus\x12>\n\x0fimu_data_status\x18\x03 \x01(\x0e\x32%.apollo.localization.ImuMsgDataStatus\"\xa9\x03\n\tMsfStatus\x12K\n\x17local_lidar_consistency\x18\x01 \x01(\x0e\x32*.apollo.localization.LocalLidarConsistency\x12>\n\x10gnss_consistency\x18\x02 \x01(\x0e\x32$.apollo.localization.GnssConsistency\x12\x41\n\x12local_lidar_status\x18\x03 \x01(\x0e\x32%.apollo.localization.LocalLidarStatus\x12\x43\n\x13local_lidar_quality\x18\x04 \x01(\x0e\x32&.apollo.localization.LocalLidarQuality\x12\x44\n\x15gnsspos_position_type\x18\x05 \x01(\x0e\x32%.apollo.localization.GnssPositionType\x12\x41\n\x12msf_running_status\x18\x06 \x01(\x0e\x32%.apollo.localization.MsfRunningStatus*\xa2\x02\n\x10LocalLidarStatus\x12\x1a\n\x16MSF_LOCAL_LIDAR_NORMAL\x10\x00\x12\x1f\n\x1bMSF_LOCAL_LIDAR_MAP_MISSING\x10\x01\x12&\n\"MSF_LOCAL_LIDAR_EXTRINSICS_MISSING\x10\x02\x12&\n\"MSF_LOCAL_LIDAR_MAP_LOADING_FAILED\x10\x03\x12\x1d\n\x19MSF_LOCAL_LIDAR_NO_OUTPUT\x10\x04\x12\x1e\n\x1aMSF_LOCAL_LIDAR_OUT_OF_MAP\x10\x05\x12\x1c\n\x18MSF_LOCAL_LIDAR_NOT_GOOD\x10\x06\x12$\n MSF_LOCAL_LIDAR_UNDEFINED_STATUS\x10\x07*\x82\x01\n\x11LocalLidarQuality\x12\x1d\n\x19MSF_LOCAL_LIDAR_VERY_GOOD\x10\x00\x12\x18\n\x14MSF_LOCAL_LIDAR_GOOD\x10\x01\x12\x1b\n\x17MSF_LOCAL_LIDAR_NOT_BAD\x10\x02\x12\x17\n\x13MSF_LOCAL_LIDAR_BAD\x10\x03*\xa7\x01\n\x15LocalLidarConsistency\x12\"\n\x1eMSF_LOCAL_LIDAR_CONSISTENCY_00\x10\x00\x12\"\n\x1eMSF_LOCAL_LIDAR_CONSISTENCY_01\x10\x01\x12\"\n\x1eMSF_LOCAL_LIDAR_CONSISTENCY_02\x10\x02\x12\"\n\x1eMSF_LOCAL_LIDAR_CONSISTENCY_03\x10\x03*\x85\x01\n\x0fGnssConsistency\x12\x1b\n\x17MSF_GNSS_CONSISTENCY_00\x10\x00\x12\x1b\n\x17MSF_GNSS_CONSISTENCY_01\x10\x01\x12\x1b\n\x17MSF_GNSS_CONSISTENCY_02\x10\x02\x12\x1b\n\x17MSF_GNSS_CONSISTENCY_03\x10\x03*\xb1\x04\n\x10GnssPositionType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x46IXEDPOS\x10\x01\x12\x0f\n\x0b\x46IXEDHEIGHT\x10\x02\x12\r\n\tFLOATCONV\x10\x04\x12\x0c\n\x08WIDELANE\x10\x05\x12\x0e\n\nNARROWLANE\x10\x06\x12\x14\n\x10\x44OPPLER_VELOCITY\x10\x08\x12\n\n\x06SINGLE\x10\x10\x12\x0b\n\x07PSRDIFF\x10\x11\x12\x08\n\x04WAAS\x10\x12\x12\x0e\n\nPROPOGATED\x10\x13\x12\x0c\n\x08OMNISTAR\x10\x14\x12\x0c\n\x08L1_FLOAT\x10 \x12\x12\n\x0eIONOFREE_FLOAT\x10!\x12\x10\n\x0cNARROW_FLOAT\x10\"\x12\n\n\x06L1_INT\x10\x30\x12\x0c\n\x08WIDE_INT\x10\x31\x12\x0e\n\nNARROW_INT\x10\x32\x12\x12\n\x0eRTK_DIRECT_INS\x10\x33\x12\x0c\n\x08INS_SBAS\x10\x34\x12\r\n\tINS_PSRSP\x10\x35\x12\x0f\n\x0bINS_PSRDIFF\x10\x36\x12\x10\n\x0cINS_RTKFLOAT\x10\x37\x12\x10\n\x0cINS_RTKFIXED\x10\x38\x12\x10\n\x0cINS_OMNISTAR\x10\x39\x12\x13\n\x0fINS_OMNISTAR_HP\x10:\x12\x13\n\x0fINS_OMNISTAR_XP\x10;\x12\x0f\n\x0bOMNISTAR_HP\x10@\x12\x0f\n\x0bOMNISTAR_XP\x10\x41\x12\x12\n\x0ePPP_CONVERGING\x10\x44\x12\x07\n\x03PPP\x10\x45\x12\x16\n\x12INS_PPP_Converging\x10I\x12\x0b\n\x07INS_PPP\x10J\x12\x0c\n\x08MSG_LOSS\x10[*t\n\x11ImuMsgDelayStatus\x12\x14\n\x10IMU_DELAY_NORMAL\x10\x00\x12\x0f\n\x0bIMU_DELAY_1\x10\x01\x12\x0f\n\x0bIMU_DELAY_2\x10\x02\x12\x0f\n\x0bIMU_DELAY_3\x10\x03\x12\x16\n\x12IMU_DELAY_ABNORMAL\x10\x04*\xa6\x01\n\x13ImuMsgMissingStatus\x12\x16\n\x12IMU_MISSING_NORMAL\x10\x00\x12\x11\n\rIMU_MISSING_1\x10\x01\x12\x11\n\rIMU_MISSING_2\x10\x02\x12\x11\n\rIMU_MISSING_3\x10\x03\x12\x11\n\rIMU_MISSING_4\x10\x04\x12\x11\n\rIMU_MISSING_5\x10\x05\x12\x18\n\x14IMU_MISSING_ABNORMAL\x10\x06*R\n\x10ImuMsgDataStatus\x12\x13\n\x0fIMU_DATA_NORMAL\x10\x00\x12\x15\n\x11IMU_DATA_ABNORMAL\x10\x01\x12\x12\n\x0eIMU_DATA_OTHER\x10\x02*\xac\x04\n\x10MsfRunningStatus\x12\x16\n\x12MSF_SOL_LIDAR_GNSS\x10\x00\x12\x12\n\x0eMSF_SOL_X_GNSS\x10\x01\x12\x13\n\x0fMSF_SOL_LIDAR_X\x10\x02\x12\x14\n\x10MSF_SOL_LIDAR_XX\x10\x03\x12\x15\n\x11MSF_SOL_LIDAR_XXX\x10\x04\x12\x0f\n\x0bMSF_SOL_X_X\x10\x05\x12\x10\n\x0cMSF_SOL_X_XX\x10\x06\x12\x11\n\rMSF_SOL_X_XXX\x10\x07\x12\x17\n\x13MSF_SSOL_LIDAR_GNSS\x10\x08\x12\x13\n\x0fMSF_SSOL_X_GNSS\x10\t\x12\x14\n\x10MSF_SSOL_LIDAR_X\x10\n\x12\x15\n\x11MSF_SSOL_LIDAR_XX\x10\x0b\x12\x16\n\x12MSF_SSOL_LIDAR_XXX\x10\x0c\x12\x10\n\x0cMSF_SSOL_X_X\x10\r\x12\x11\n\rMSF_SSOL_X_XX\x10\x0e\x12\x12\n\x0eMSF_SSOL_X_XXX\x10\x0f\x12\x18\n\x14MSF_NOSOL_LIDAR_GNSS\x10\x10\x12\x14\n\x10MSF_NOSOL_X_GNSS\x10\x11\x12\x15\n\x11MSF_NOSOL_LIDAR_X\x10\x12\x12\x16\n\x12MSF_NOSOL_LIDAR_XX\x10\x13\x12\x17\n\x13MSF_NOSOL_LIDAR_XXX\x10\x14\x12\x11\n\rMSF_NOSOL_X_X\x10\x15\x12\x12\n\x0eMSF_NOSOL_X_XX\x10\x16\x12\x13\n\x0fMSF_NOSOL_X_XXX\x10\x17\x12\x14\n\x10MSF_RUNNING_INIT\x10\x18'
)

_LOCALLIDARSTATUS = _descriptor.EnumDescriptor(
  name='LocalLidarStatus',
  full_name='apollo.localization.LocalLidarStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_MAP_MISSING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_EXTRINSICS_MISSING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_MAP_LOADING_FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_NO_OUTPUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_OUT_OF_MAP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_NOT_GOOD', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_UNDEFINED_STATUS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=729,
  serialized_end=1019,
)
_sym_db.RegisterEnumDescriptor(_LOCALLIDARSTATUS)

LocalLidarStatus = enum_type_wrapper.EnumTypeWrapper(_LOCALLIDARSTATUS)
_LOCALLIDARQUALITY = _descriptor.EnumDescriptor(
  name='LocalLidarQuality',
  full_name='apollo.localization.LocalLidarQuality',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_VERY_GOOD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_GOOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_NOT_BAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_BAD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1022,
  serialized_end=1152,
)
_sym_db.RegisterEnumDescriptor(_LOCALLIDARQUALITY)

LocalLidarQuality = enum_type_wrapper.EnumTypeWrapper(_LOCALLIDARQUALITY)
_LOCALLIDARCONSISTENCY = _descriptor.EnumDescriptor(
  name='LocalLidarConsistency',
  full_name='apollo.localization.LocalLidarConsistency',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_CONSISTENCY_00', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_CONSISTENCY_01', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_CONSISTENCY_02', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_LOCAL_LIDAR_CONSISTENCY_03', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1155,
  serialized_end=1322,
)
_sym_db.RegisterEnumDescriptor(_LOCALLIDARCONSISTENCY)

LocalLidarConsistency = enum_type_wrapper.EnumTypeWrapper(_LOCALLIDARCONSISTENCY)
_GNSSCONSISTENCY = _descriptor.EnumDescriptor(
  name='GnssConsistency',
  full_name='apollo.localization.GnssConsistency',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSF_GNSS_CONSISTENCY_00', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_GNSS_CONSISTENCY_01', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_GNSS_CONSISTENCY_02', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_GNSS_CONSISTENCY_03', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1325,
  serialized_end=1458,
)
_sym_db.RegisterEnumDescriptor(_GNSSCONSISTENCY)

GnssConsistency = enum_type_wrapper.EnumTypeWrapper(_GNSSCONSISTENCY)
_GNSSPOSITIONTYPE = _descriptor.EnumDescriptor(
  name='GnssPositionType',
  full_name='apollo.localization.GnssPositionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXEDPOS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXEDHEIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOATCONV', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIDELANE', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWLANE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOPPLER_VELOCITY', index=6, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=7, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PSRDIFF', index=8, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAAS', index=9, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOGATED', index=10, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR', index=11, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='L1_FLOAT', index=12, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IONOFREE_FLOAT', index=13, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_FLOAT', index=14, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='L1_INT', index=15, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIDE_INT', index=16, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_INT', index=17, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTK_DIRECT_INS', index=18, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_SBAS', index=19, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PSRSP', index=20, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PSRDIFF', index=21, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_RTKFLOAT', index=22, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_RTKFIXED', index=23, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR', index=24, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR_HP', index=25, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR_XP', index=26, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR_HP', index=27, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR_XP', index=28, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PPP_CONVERGING', index=29, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PPP', index=30, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PPP_Converging', index=31, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PPP', index=32, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSG_LOSS', index=33, number=91,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1461,
  serialized_end=2022,
)
_sym_db.RegisterEnumDescriptor(_GNSSPOSITIONTYPE)

GnssPositionType = enum_type_wrapper.EnumTypeWrapper(_GNSSPOSITIONTYPE)
_IMUMSGDELAYSTATUS = _descriptor.EnumDescriptor(
  name='ImuMsgDelayStatus',
  full_name='apollo.localization.ImuMsgDelayStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMU_DELAY_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DELAY_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DELAY_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DELAY_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DELAY_ABNORMAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2024,
  serialized_end=2140,
)
_sym_db.RegisterEnumDescriptor(_IMUMSGDELAYSTATUS)

ImuMsgDelayStatus = enum_type_wrapper.EnumTypeWrapper(_IMUMSGDELAYSTATUS)
_IMUMSGMISSINGSTATUS = _descriptor.EnumDescriptor(
  name='ImuMsgMissingStatus',
  full_name='apollo.localization.ImuMsgMissingStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_MISSING_ABNORMAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2143,
  serialized_end=2309,
)
_sym_db.RegisterEnumDescriptor(_IMUMSGMISSINGSTATUS)

ImuMsgMissingStatus = enum_type_wrapper.EnumTypeWrapper(_IMUMSGMISSINGSTATUS)
_IMUMSGDATASTATUS = _descriptor.EnumDescriptor(
  name='ImuMsgDataStatus',
  full_name='apollo.localization.ImuMsgDataStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMU_DATA_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DATA_ABNORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMU_DATA_OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2311,
  serialized_end=2393,
)
_sym_db.RegisterEnumDescriptor(_IMUMSGDATASTATUS)

ImuMsgDataStatus = enum_type_wrapper.EnumTypeWrapper(_IMUMSGDATASTATUS)
_MSFRUNNINGSTATUS = _descriptor.EnumDescriptor(
  name='MsfRunningStatus',
  full_name='apollo.localization.MsfRunningStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_LIDAR_GNSS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_X_GNSS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_LIDAR_X', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_LIDAR_XX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_LIDAR_XXX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_X_X', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_X_XX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SOL_X_XXX', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_LIDAR_GNSS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_X_GNSS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_LIDAR_X', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_LIDAR_XX', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_LIDAR_XXX', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_X_X', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_X_XX', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_SSOL_X_XXX', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_LIDAR_GNSS', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_X_GNSS', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_LIDAR_X', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_LIDAR_XX', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_LIDAR_XXX', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_X_X', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_X_XX', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_NOSOL_X_XXX', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSF_RUNNING_INIT', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2396,
  serialized_end=2952,
)
_sym_db.RegisterEnumDescriptor(_MSFRUNNINGSTATUS)

MsfRunningStatus = enum_type_wrapper.EnumTypeWrapper(_MSFRUNNINGSTATUS)
MSF_LOCAL_LIDAR_NORMAL = 0
MSF_LOCAL_LIDAR_MAP_MISSING = 1
MSF_LOCAL_LIDAR_EXTRINSICS_MISSING = 2
MSF_LOCAL_LIDAR_MAP_LOADING_FAILED = 3
MSF_LOCAL_LIDAR_NO_OUTPUT = 4
MSF_LOCAL_LIDAR_OUT_OF_MAP = 5
MSF_LOCAL_LIDAR_NOT_GOOD = 6
MSF_LOCAL_LIDAR_UNDEFINED_STATUS = 7
MSF_LOCAL_LIDAR_VERY_GOOD = 0
MSF_LOCAL_LIDAR_GOOD = 1
MSF_LOCAL_LIDAR_NOT_BAD = 2
MSF_LOCAL_LIDAR_BAD = 3
MSF_LOCAL_LIDAR_CONSISTENCY_00 = 0
MSF_LOCAL_LIDAR_CONSISTENCY_01 = 1
MSF_LOCAL_LIDAR_CONSISTENCY_02 = 2
MSF_LOCAL_LIDAR_CONSISTENCY_03 = 3
MSF_GNSS_CONSISTENCY_00 = 0
MSF_GNSS_CONSISTENCY_01 = 1
MSF_GNSS_CONSISTENCY_02 = 2
MSF_GNSS_CONSISTENCY_03 = 3
NONE = 0
FIXEDPOS = 1
FIXEDHEIGHT = 2
FLOATCONV = 4
WIDELANE = 5
NARROWLANE = 6
DOPPLER_VELOCITY = 8
SINGLE = 16
PSRDIFF = 17
WAAS = 18
PROPOGATED = 19
OMNISTAR = 20
L1_FLOAT = 32
IONOFREE_FLOAT = 33
NARROW_FLOAT = 34
L1_INT = 48
WIDE_INT = 49
NARROW_INT = 50
RTK_DIRECT_INS = 51
INS_SBAS = 52
INS_PSRSP = 53
INS_PSRDIFF = 54
INS_RTKFLOAT = 55
INS_RTKFIXED = 56
INS_OMNISTAR = 57
INS_OMNISTAR_HP = 58
INS_OMNISTAR_XP = 59
OMNISTAR_HP = 64
OMNISTAR_XP = 65
PPP_CONVERGING = 68
PPP = 69
INS_PPP_Converging = 73
INS_PPP = 74
MSG_LOSS = 91
IMU_DELAY_NORMAL = 0
IMU_DELAY_1 = 1
IMU_DELAY_2 = 2
IMU_DELAY_3 = 3
IMU_DELAY_ABNORMAL = 4
IMU_MISSING_NORMAL = 0
IMU_MISSING_1 = 1
IMU_MISSING_2 = 2
IMU_MISSING_3 = 3
IMU_MISSING_4 = 4
IMU_MISSING_5 = 5
IMU_MISSING_ABNORMAL = 6
IMU_DATA_NORMAL = 0
IMU_DATA_ABNORMAL = 1
IMU_DATA_OTHER = 2
MSF_SOL_LIDAR_GNSS = 0
MSF_SOL_X_GNSS = 1
MSF_SOL_LIDAR_X = 2
MSF_SOL_LIDAR_XX = 3
MSF_SOL_LIDAR_XXX = 4
MSF_SOL_X_X = 5
MSF_SOL_X_XX = 6
MSF_SOL_X_XXX = 7
MSF_SSOL_LIDAR_GNSS = 8
MSF_SSOL_X_GNSS = 9
MSF_SSOL_LIDAR_X = 10
MSF_SSOL_LIDAR_XX = 11
MSF_SSOL_LIDAR_XXX = 12
MSF_SSOL_X_X = 13
MSF_SSOL_X_XX = 14
MSF_SSOL_X_XXX = 15
MSF_NOSOL_LIDAR_GNSS = 16
MSF_NOSOL_X_GNSS = 17
MSF_NOSOL_LIDAR_X = 18
MSF_NOSOL_LIDAR_XX = 19
MSF_NOSOL_LIDAR_XXX = 20
MSF_NOSOL_X_X = 21
MSF_NOSOL_X_XX = 22
MSF_NOSOL_X_XXX = 23
MSF_RUNNING_INIT = 24



_MSFSENSORMSGSTATUS = _descriptor.Descriptor(
  name='MsfSensorMsgStatus',
  full_name='apollo.localization.MsfSensorMsgStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='imu_delay_status', full_name='apollo.localization.MsfSensorMsgStatus.imu_delay_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu_missing_status', full_name='apollo.localization.MsfSensorMsgStatus.imu_missing_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu_data_status', full_name='apollo.localization.MsfSensorMsgStatus.imu_data_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=298,
)


_MSFSTATUS = _descriptor.Descriptor(
  name='MsfStatus',
  full_name='apollo.localization.MsfStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_lidar_consistency', full_name='apollo.localization.MsfStatus.local_lidar_consistency', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_consistency', full_name='apollo.localization.MsfStatus.gnss_consistency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_lidar_status', full_name='apollo.localization.MsfStatus.local_lidar_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_lidar_quality', full_name='apollo.localization.MsfStatus.local_lidar_quality', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnsspos_position_type', full_name='apollo.localization.MsfStatus.gnsspos_position_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msf_running_status', full_name='apollo.localization.MsfStatus.msf_running_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=726,
)

_MSFSENSORMSGSTATUS.fields_by_name['imu_delay_status'].enum_type = _IMUMSGDELAYSTATUS
_MSFSENSORMSGSTATUS.fields_by_name['imu_missing_status'].enum_type = _IMUMSGMISSINGSTATUS
_MSFSENSORMSGSTATUS.fields_by_name['imu_data_status'].enum_type = _IMUMSGDATASTATUS
_MSFSTATUS.fields_by_name['local_lidar_consistency'].enum_type = _LOCALLIDARCONSISTENCY
_MSFSTATUS.fields_by_name['gnss_consistency'].enum_type = _GNSSCONSISTENCY
_MSFSTATUS.fields_by_name['local_lidar_status'].enum_type = _LOCALLIDARSTATUS
_MSFSTATUS.fields_by_name['local_lidar_quality'].enum_type = _LOCALLIDARQUALITY
_MSFSTATUS.fields_by_name['gnsspos_position_type'].enum_type = _GNSSPOSITIONTYPE
_MSFSTATUS.fields_by_name['msf_running_status'].enum_type = _MSFRUNNINGSTATUS
DESCRIPTOR.message_types_by_name['MsfSensorMsgStatus'] = _MSFSENSORMSGSTATUS
DESCRIPTOR.message_types_by_name['MsfStatus'] = _MSFSTATUS
DESCRIPTOR.enum_types_by_name['LocalLidarStatus'] = _LOCALLIDARSTATUS
DESCRIPTOR.enum_types_by_name['LocalLidarQuality'] = _LOCALLIDARQUALITY
DESCRIPTOR.enum_types_by_name['LocalLidarConsistency'] = _LOCALLIDARCONSISTENCY
DESCRIPTOR.enum_types_by_name['GnssConsistency'] = _GNSSCONSISTENCY
DESCRIPTOR.enum_types_by_name['GnssPositionType'] = _GNSSPOSITIONTYPE
DESCRIPTOR.enum_types_by_name['ImuMsgDelayStatus'] = _IMUMSGDELAYSTATUS
DESCRIPTOR.enum_types_by_name['ImuMsgMissingStatus'] = _IMUMSGMISSINGSTATUS
DESCRIPTOR.enum_types_by_name['ImuMsgDataStatus'] = _IMUMSGDATASTATUS
DESCRIPTOR.enum_types_by_name['MsfRunningStatus'] = _MSFRUNNINGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsfSensorMsgStatus = _reflection.GeneratedProtocolMessageType('MsfSensorMsgStatus', (_message.Message,), {
  'DESCRIPTOR' : _MSFSENSORMSGSTATUS,
  '__module__' : 'modules.localization.proto.localization_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.MsfSensorMsgStatus)
  })
_sym_db.RegisterMessage(MsfSensorMsgStatus)

MsfStatus = _reflection.GeneratedProtocolMessageType('MsfStatus', (_message.Message,), {
  'DESCRIPTOR' : _MSFSTATUS,
  '__module__' : 'modules.localization.proto.localization_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.MsfStatus)
  })
_sym_db.RegisterMessage(MsfStatus)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/lidar/proto/lidar_parameter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/lidar/proto/lidar_parameter.proto',
  package='apollo.drivers.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/drivers/lidar/proto/lidar_parameter.proto\x12\x14\x61pollo.drivers.lidar\"\xeb\x01\n\x0eLidarParameter\x12>\n\x05\x62rand\x18\x01 \x02(\x0e\x32/.apollo.drivers.lidar.LidarParameter.LidarBrand\"4\n\nLidarBrand\x12\x0c\n\x08VELODYNE\x10\x00\x12\t\n\x05HESAI\x10\x01\x12\r\n\tROBOSENSE\x10\x02\"c\n\x0eLidarChannelId\x12\x13\n\x0f\x43HANNEL_ID_ZERO\x10\x00\x12\x12\n\x0e\x43HANNEL_ID_ONE\x10\x01\x12\x12\n\x0e\x43HANNEL_ID_TWO\x10\x02\x12\x14\n\x10\x43HANNEL_ID_THREE\x10\x03'
)



_LIDARPARAMETER_LIDARBRAND = _descriptor.EnumDescriptor(
  name='LidarBrand',
  full_name='apollo.drivers.lidar.LidarParameter.LidarBrand',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VELODYNE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HESAI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROBOSENSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=158,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_LIDARPARAMETER_LIDARBRAND)

_LIDARPARAMETER_LIDARCHANNELID = _descriptor.EnumDescriptor(
  name='LidarChannelId',
  full_name='apollo.drivers.lidar.LidarParameter.LidarChannelId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_ONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_TWO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_ID_THREE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=212,
  serialized_end=311,
)
_sym_db.RegisterEnumDescriptor(_LIDARPARAMETER_LIDARCHANNELID)


_LIDARPARAMETER = _descriptor.Descriptor(
  name='LidarParameter',
  full_name='apollo.drivers.lidar.LidarParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brand', full_name='apollo.drivers.lidar.LidarParameter.brand', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LIDARPARAMETER_LIDARBRAND,
    _LIDARPARAMETER_LIDARCHANNELID,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=311,
)

_LIDARPARAMETER.fields_by_name['brand'].enum_type = _LIDARPARAMETER_LIDARBRAND
_LIDARPARAMETER_LIDARBRAND.containing_type = _LIDARPARAMETER
_LIDARPARAMETER_LIDARCHANNELID.containing_type = _LIDARPARAMETER
DESCRIPTOR.message_types_by_name['LidarParameter'] = _LIDARPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LidarParameter = _reflection.GeneratedProtocolMessageType('LidarParameter', (_message.Message,), {
  'DESCRIPTOR' : _LIDARPARAMETER,
  '__module__' : 'modules.drivers.lidar.proto.lidar_parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.lidar.LidarParameter)
  })
_sym_db.RegisterMessage(LidarParameter)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/examples/proto/examples.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/examples/proto/examples.proto',
  package='apollo.cyber.examples.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#cyber/examples/proto/examples.proto\x12\x1b\x61pollo.cyber.examples.proto\"5\n\x0cSamplesTest1\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x11\n\tcase_name\x18\x02 \x01(\t\"S\n\x07\x43hatter\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x17\n\x0flidar_timestamp\x18\x02 \x01(\x04\x12\x0b\n\x03seq\x18\x03 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"<\n\x06\x44river\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0e\n\x06msg_id\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\x04'
)




_SAMPLESTEST1 = _descriptor.Descriptor(
  name='SamplesTest1',
  full_name='apollo.cyber.examples.proto.SamplesTest1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.examples.proto.SamplesTest1.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_name', full_name='apollo.cyber.examples.proto.SamplesTest1.case_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=121,
)


_CHATTER = _descriptor.Descriptor(
  name='Chatter',
  full_name='apollo.cyber.examples.proto.Chatter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.cyber.examples.proto.Chatter.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_timestamp', full_name='apollo.cyber.examples.proto.Chatter.lidar_timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='apollo.cyber.examples.proto.Chatter.seq', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.examples.proto.Chatter.content', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=206,
)


_DRIVER = _descriptor.Descriptor(
  name='Driver',
  full_name='apollo.cyber.examples.proto.Driver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.examples.proto.Driver.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='apollo.cyber.examples.proto.Driver.msg_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.cyber.examples.proto.Driver.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=268,
)

DESCRIPTOR.message_types_by_name['SamplesTest1'] = _SAMPLESTEST1
DESCRIPTOR.message_types_by_name['Chatter'] = _CHATTER
DESCRIPTOR.message_types_by_name['Driver'] = _DRIVER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SamplesTest1 = _reflection.GeneratedProtocolMessageType('SamplesTest1', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLESTEST1,
  '__module__' : 'cyber.examples.proto.examples_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.examples.proto.SamplesTest1)
  })
_sym_db.RegisterMessage(SamplesTest1)

Chatter = _reflection.GeneratedProtocolMessageType('Chatter', (_message.Message,), {
  'DESCRIPTOR' : _CHATTER,
  '__module__' : 'cyber.examples.proto.examples_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.examples.proto.Chatter)
  })
_sym_db.RegisterMessage(Chatter)

Driver = _reflection.GeneratedProtocolMessageType('Driver', (_message.Message,), {
  'DESCRIPTOR' : _DRIVER,
  '__module__' : 'cyber.examples.proto.examples_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.examples.proto.Driver)
  })
_sym_db.RegisterMessage(Driver)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_camera.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_camera.proto',
  package='apollo.perception.camera',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/perception/proto/perception_camera.proto\x12\x18\x61pollo.perception.camera\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\"n\n\x12LaneLineCubicCurve\x12\x15\n\rlongitude_min\x18\x01 \x01(\x02\x12\x15\n\rlongitude_max\x18\x02 \x01(\x02\x12\t\n\x01\x61\x18\x03 \x01(\x02\x12\t\n\x01\x62\x18\x04 \x01(\x02\x12\t\n\x01\x63\x18\x05 \x01(\x02\x12\t\n\x01\x64\x18\x06 \x01(\x02\"W\n\tEndPoints\x12%\n\x05start\x18\x01 \x01(\x0b\x32\x16.apollo.common.Point2D\x12#\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point2D\"\xaf\x04\n\x0e\x43\x61meraLaneLine\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.apollo.perception.camera.LaneLineType\x12@\n\x08pos_type\x18\x02 \x01(\x0e\x32..apollo.perception.camera.LaneLinePositionType\x12H\n\x12\x63urve_camera_coord\x18\x03 \x01(\x0b\x32,.apollo.perception.camera.LaneLineCubicCurve\x12G\n\x11\x63urve_image_coord\x18\x04 \x01(\x0b\x32,.apollo.perception.camera.LaneLineCubicCurve\x12\x36\n\x16\x63urve_camera_point_set\x18\x05 \x03(\x0b\x32\x16.apollo.common.Point3D\x12\x35\n\x15\x63urve_image_point_set\x18\x06 \x03(\x0b\x32\x16.apollo.common.Point2D\x12@\n\x13image_end_point_set\x18\x07 \x03(\x0b\x32#.apollo.perception.camera.EndPoints\x12\x10\n\x08track_id\x18\x08 \x01(\x05\x12\x12\n\nconfidence\x18\t \x01(\x02\x12;\n\x08use_type\x18\n \x01(\x0e\x32).apollo.perception.camera.LaneLineUseType\">\n\x10\x43\x61meraCalibrator\x12\x13\n\x0bpitch_angle\x18\x01 \x01(\x02\x12\x15\n\rcamera_height\x18\x02 \x01(\x02\"\xad\x03\n\x0e\x43\x61meraObstacle\x12\x37\n\x08obstacle\x18\x01 \x01(\x0b\x32%.apollo.perception.PerceptionObstacle\x12\x41\n\x04type\x18\x15 \x01(\x0e\x32\x33.apollo.perception.camera.CameraObstacle.CameraType\x12\x12\n\ntype_probs\x18\x16 \x03(\x02\x12*\n\nupper_left\x18\x17 \x01(\x0b\x32\x16.apollo.common.Point2D\x12+\n\x0blower_right\x18\x18 \x01(\x0b\x32\x16.apollo.common.Point2D\x12*\n\nkey_points\x18\x19 \x03(\x0b\x32\x16.apollo.common.Point2D\x12\x15\n\rdebug_message\x18\x1a \x03(\t\"o\n\nCameraType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUNKNOWN_MOVABLE\x10\x01\x12\x15\n\x11UNKNOWN_UNMOVABLE\x10\x02\x12\x0e\n\nPEDESTRIAN\x10\x03\x12\x0b\n\x07\x42ICYCLE\x10\x04\x12\x0b\n\x07VEHICLE\x10\x05\"\xe2\x02\n\x0b\x43\x61meraDebug\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x14\n\x0csource_topic\x18\x02 \x01(\t\x12I\n\nerror_code\x18\x03 \x01(\x0e\x32).apollo.perception.camera.CameraErrorCode:\nERROR_NONE\x12\x45\n\x11\x63\x61mera_calibrator\x18\x04 \x01(\x0b\x32*.apollo.perception.camera.CameraCalibrator\x12\x41\n\x0f\x63\x61mera_laneline\x18\x05 \x03(\x0b\x32(.apollo.perception.camera.CameraLaneLine\x12\x41\n\x0f\x63\x61mera_obstacle\x18\x06 \x03(\x0b\x32(.apollo.perception.camera.CameraObstacle*4\n\x0f\x43\x61meraErrorCode\x12\x0e\n\nERROR_NONE\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01*V\n\x0cLaneLineType\x12\x10\n\x0cWHITE_DASHED\x10\x00\x12\x0f\n\x0bWHITE_SOLID\x10\x01\x12\x11\n\rYELLOW_DASHED\x10\x02\x12\x10\n\x0cYELLOW_SOLID\x10\x03*\x88\x02\n\x14LaneLinePositionType\x12\x19\n\x0c\x42OLLARD_LEFT\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0b\x46OURTH_LEFT\x10\xfc\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x17\n\nTHIRD_LEFT\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rADJACENT_LEFT\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x08\x45GO_LEFT\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\r\n\tEGO_RIGHT\x10\x01\x12\x12\n\x0e\x41\x44JACENT_RIGHT\x10\x02\x12\x0f\n\x0bTHIRD_RIGHT\x10\x03\x12\x10\n\x0c\x46OURTH_RIGHT\x10\x04\x12\x11\n\rBOLLARD_RIGHT\x10\x05\x12\t\n\x05OTHER\x10\x06\x12\x0b\n\x07UNKNOWN\x10\x07*(\n\x0fLaneLineUseType\x12\x08\n\x04REAL\x10\x00\x12\x0b\n\x07VIRTUAL\x10\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,])

_CAMERAERRORCODE = _descriptor.EnumDescriptor(
  name='CameraErrorCode',
  full_name='apollo.perception.camera.CameraErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1818,
  serialized_end=1870,
)
_sym_db.RegisterEnumDescriptor(_CAMERAERRORCODE)

CameraErrorCode = enum_type_wrapper.EnumTypeWrapper(_CAMERAERRORCODE)
_LANELINETYPE = _descriptor.EnumDescriptor(
  name='LaneLineType',
  full_name='apollo.perception.camera.LaneLineType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WHITE_DASHED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WHITE_SOLID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW_DASHED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW_SOLID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1872,
  serialized_end=1958,
)
_sym_db.RegisterEnumDescriptor(_LANELINETYPE)

LaneLineType = enum_type_wrapper.EnumTypeWrapper(_LANELINETYPE)
_LANELINEPOSITIONTYPE = _descriptor.EnumDescriptor(
  name='LaneLinePositionType',
  full_name='apollo.perception.camera.LaneLinePositionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOLLARD_LEFT', index=0, number=-5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOURTH_LEFT', index=1, number=-4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THIRD_LEFT', index=2, number=-3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADJACENT_LEFT', index=3, number=-2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGO_LEFT', index=4, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGO_RIGHT', index=5, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADJACENT_RIGHT', index=6, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THIRD_RIGHT', index=7, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOURTH_RIGHT', index=8, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLARD_RIGHT', index=9, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=10, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=11, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1961,
  serialized_end=2225,
)
_sym_db.RegisterEnumDescriptor(_LANELINEPOSITIONTYPE)

LaneLinePositionType = enum_type_wrapper.EnumTypeWrapper(_LANELINEPOSITIONTYPE)
_LANELINEUSETYPE = _descriptor.EnumDescriptor(
  name='LaneLineUseType',
  full_name='apollo.perception.camera.LaneLineUseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2227,
  serialized_end=2267,
)
_sym_db.RegisterEnumDescriptor(_LANELINEUSETYPE)

LaneLineUseType = enum_type_wrapper.EnumTypeWrapper(_LANELINEUSETYPE)
ERROR_NONE = 0
ERROR_UNKNOWN = 1
WHITE_DASHED = 0
WHITE_SOLID = 1
YELLOW_DASHED = 2
YELLOW_SOLID = 3
BOLLARD_LEFT = -5
FOURTH_LEFT = -4
THIRD_LEFT = -3
ADJACENT_LEFT = -2
EGO_LEFT = -1
EGO_RIGHT = 1
ADJACENT_RIGHT = 2
THIRD_RIGHT = 3
FOURTH_RIGHT = 4
BOLLARD_RIGHT = 5
OTHER = 6
UNKNOWN = 7
REAL = 0
VIRTUAL = 1


_CAMERAOBSTACLE_CAMERATYPE = _descriptor.EnumDescriptor(
  name='CameraType',
  full_name='apollo.perception.camera.CameraObstacle.CameraType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MOVABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNMOVABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1348,
  serialized_end=1459,
)
_sym_db.RegisterEnumDescriptor(_CAMERAOBSTACLE_CAMERATYPE)


_LANELINECUBICCURVE = _descriptor.Descriptor(
  name='LaneLineCubicCurve',
  full_name='apollo.perception.camera.LaneLineCubicCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitude_min', full_name='apollo.perception.camera.LaneLineCubicCurve.longitude_min', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_max', full_name='apollo.perception.camera.LaneLineCubicCurve.longitude_max', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.perception.camera.LaneLineCubicCurve.a', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='apollo.perception.camera.LaneLineCubicCurve.b', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='apollo.perception.camera.LaneLineCubicCurve.c', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='apollo.perception.camera.LaneLineCubicCurve.d', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=312,
)


_ENDPOINTS = _descriptor.Descriptor(
  name='EndPoints',
  full_name='apollo.perception.camera.EndPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='apollo.perception.camera.EndPoints.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='apollo.perception.camera.EndPoints.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=401,
)


_CAMERALANELINE = _descriptor.Descriptor(
  name='CameraLaneLine',
  full_name='apollo.perception.camera.CameraLaneLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.CameraLaneLine.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_type', full_name='apollo.perception.camera.CameraLaneLine.pos_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_camera_coord', full_name='apollo.perception.camera.CameraLaneLine.curve_camera_coord', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_image_coord', full_name='apollo.perception.camera.CameraLaneLine.curve_image_coord', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_camera_point_set', full_name='apollo.perception.camera.CameraLaneLine.curve_camera_point_set', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_image_point_set', full_name='apollo.perception.camera.CameraLaneLine.curve_image_point_set', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_end_point_set', full_name='apollo.perception.camera.CameraLaneLine.image_end_point_set', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_id', full_name='apollo.perception.camera.CameraLaneLine.track_id', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.perception.camera.CameraLaneLine.confidence', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_type', full_name='apollo.perception.camera.CameraLaneLine.use_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=963,
)


_CAMERACALIBRATOR = _descriptor.Descriptor(
  name='CameraCalibrator',
  full_name='apollo.perception.camera.CameraCalibrator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pitch_angle', full_name='apollo.perception.camera.CameraCalibrator.pitch_angle', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_height', full_name='apollo.perception.camera.CameraCalibrator.camera_height', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1027,
)


_CAMERAOBSTACLE = _descriptor.Descriptor(
  name='CameraObstacle',
  full_name='apollo.perception.camera.CameraObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle', full_name='apollo.perception.camera.CameraObstacle.obstacle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.CameraObstacle.type', index=1,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_probs', full_name='apollo.perception.camera.CameraObstacle.type_probs', index=2,
      number=22, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_left', full_name='apollo.perception.camera.CameraObstacle.upper_left', index=3,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_right', full_name='apollo.perception.camera.CameraObstacle.lower_right', index=4,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_points', full_name='apollo.perception.camera.CameraObstacle.key_points', index=5,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='apollo.perception.camera.CameraObstacle.debug_message', index=6,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMERAOBSTACLE_CAMERATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1459,
)


_CAMERADEBUG = _descriptor.Descriptor(
  name='CameraDebug',
  full_name='apollo.perception.camera.CameraDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.camera.CameraDebug.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_topic', full_name='apollo.perception.camera.CameraDebug.source_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.perception.camera.CameraDebug.error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_calibrator', full_name='apollo.perception.camera.CameraDebug.camera_calibrator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_laneline', full_name='apollo.perception.camera.CameraDebug.camera_laneline', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_obstacle', full_name='apollo.perception.camera.CameraDebug.camera_obstacle', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=1816,
)

_ENDPOINTS.fields_by_name['start'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_ENDPOINTS.fields_by_name['end'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERALANELINE.fields_by_name['type'].enum_type = _LANELINETYPE
_CAMERALANELINE.fields_by_name['pos_type'].enum_type = _LANELINEPOSITIONTYPE
_CAMERALANELINE.fields_by_name['curve_camera_coord'].message_type = _LANELINECUBICCURVE
_CAMERALANELINE.fields_by_name['curve_image_coord'].message_type = _LANELINECUBICCURVE
_CAMERALANELINE.fields_by_name['curve_camera_point_set'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_CAMERALANELINE.fields_by_name['curve_image_point_set'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERALANELINE.fields_by_name['image_end_point_set'].message_type = _ENDPOINTS
_CAMERALANELINE.fields_by_name['use_type'].enum_type = _LANELINEUSETYPE
_CAMERAOBSTACLE.fields_by_name['obstacle'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE
_CAMERAOBSTACLE.fields_by_name['type'].enum_type = _CAMERAOBSTACLE_CAMERATYPE
_CAMERAOBSTACLE.fields_by_name['upper_left'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE.fields_by_name['lower_right'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE.fields_by_name['key_points'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE_CAMERATYPE.containing_type = _CAMERAOBSTACLE
_CAMERADEBUG.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CAMERADEBUG.fields_by_name['error_code'].enum_type = _CAMERAERRORCODE
_CAMERADEBUG.fields_by_name['camera_calibrator'].message_type = _CAMERACALIBRATOR
_CAMERADEBUG.fields_by_name['camera_laneline'].message_type = _CAMERALANELINE
_CAMERADEBUG.fields_by_name['camera_obstacle'].message_type = _CAMERAOBSTACLE
DESCRIPTOR.message_types_by_name['LaneLineCubicCurve'] = _LANELINECUBICCURVE
DESCRIPTOR.message_types_by_name['EndPoints'] = _ENDPOINTS
DESCRIPTOR.message_types_by_name['CameraLaneLine'] = _CAMERALANELINE
DESCRIPTOR.message_types_by_name['CameraCalibrator'] = _CAMERACALIBRATOR
DESCRIPTOR.message_types_by_name['CameraObstacle'] = _CAMERAOBSTACLE
DESCRIPTOR.message_types_by_name['CameraDebug'] = _CAMERADEBUG
DESCRIPTOR.enum_types_by_name['CameraErrorCode'] = _CAMERAERRORCODE
DESCRIPTOR.enum_types_by_name['LaneLineType'] = _LANELINETYPE
DESCRIPTOR.enum_types_by_name['LaneLinePositionType'] = _LANELINEPOSITIONTYPE
DESCRIPTOR.enum_types_by_name['LaneLineUseType'] = _LANELINEUSETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneLineCubicCurve = _reflection.GeneratedProtocolMessageType('LaneLineCubicCurve', (_message.Message,), {
  'DESCRIPTOR' : _LANELINECUBICCURVE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.LaneLineCubicCurve)
  })
_sym_db.RegisterMessage(LaneLineCubicCurve)

EndPoints = _reflection.GeneratedProtocolMessageType('EndPoints', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTS,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.EndPoints)
  })
_sym_db.RegisterMessage(EndPoints)

CameraLaneLine = _reflection.GeneratedProtocolMessageType('CameraLaneLine', (_message.Message,), {
  'DESCRIPTOR' : _CAMERALANELINE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraLaneLine)
  })
_sym_db.RegisterMessage(CameraLaneLine)

CameraCalibrator = _reflection.GeneratedProtocolMessageType('CameraCalibrator', (_message.Message,), {
  'DESCRIPTOR' : _CAMERACALIBRATOR,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraCalibrator)
  })
_sym_db.RegisterMessage(CameraCalibrator)

CameraObstacle = _reflection.GeneratedProtocolMessageType('CameraObstacle', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAOBSTACLE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraObstacle)
  })
_sym_db.RegisterMessage(CameraObstacle)

CameraDebug = _reflection.GeneratedProtocolMessageType('CameraDebug', (_message.Message,), {
  'DESCRIPTOR' : _CAMERADEBUG,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraDebug)
  })
_sym_db.RegisterMessage(CameraDebug)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/prediction_point.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/prediction_point.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/prediction/proto/prediction_point.proto\x12\x11\x61pollo.prediction\"E\n\x13PredictionPathPoint\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x18\n\x10velocity_heading\x18\x03 \x01(\x01\"j\n\x19PredictionTrajectoryPoint\x12:\n\npath_point\x18\x01 \x02(\x0b\x32&.apollo.prediction.PredictionPathPoint\x12\x11\n\ttimestamp\x18\x02 \x02(\x01'
)




_PREDICTIONPATHPOINT = _descriptor.Descriptor(
  name='PredictionPathPoint',
  full_name='apollo.prediction.PredictionPathPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.prediction.PredictionPathPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.prediction.PredictionPathPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_heading', full_name='apollo.prediction.PredictionPathPoint.velocity_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=139,
)


_PREDICTIONTRAJECTORYPOINT = _descriptor.Descriptor(
  name='PredictionTrajectoryPoint',
  full_name='apollo.prediction.PredictionTrajectoryPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.prediction.PredictionTrajectoryPoint.path_point', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.PredictionTrajectoryPoint.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=247,
)

_PREDICTIONTRAJECTORYPOINT.fields_by_name['path_point'].message_type = _PREDICTIONPATHPOINT
DESCRIPTOR.message_types_by_name['PredictionPathPoint'] = _PREDICTIONPATHPOINT
DESCRIPTOR.message_types_by_name['PredictionTrajectoryPoint'] = _PREDICTIONTRAJECTORYPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionPathPoint = _reflection.GeneratedProtocolMessageType('PredictionPathPoint', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONPATHPOINT,
  '__module__' : 'modules.prediction.proto.prediction_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionPathPoint)
  })
_sym_db.RegisterMessage(PredictionPathPoint)

PredictionTrajectoryPoint = _reflection.GeneratedProtocolMessageType('PredictionTrajectoryPoint', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONTRAJECTORYPOINT,
  '__module__' : 'modules.prediction.proto.prediction_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionTrajectoryPoint)
  })
_sym_db.RegisterMessage(PredictionTrajectoryPoint)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/routing/proto/topo_graph.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/routing/proto/topo_graph.proto',
  package='apollo.routing',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/routing/proto/topo_graph.proto\x12\x0e\x61pollo.routing\x1a$modules/map/proto/map_geometry.proto\"\x17\n\nCurvePoint\x12\t\n\x01s\x18\x01 \x01(\x01\"`\n\nCurveRange\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.apollo.routing.CurvePoint\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.apollo.routing.CurvePoint\"\xe9\x01\n\x04Node\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\x0e\n\x06length\x18\x02 \x01(\x01\x12,\n\x08left_out\x18\x03 \x03(\x0b\x32\x1a.apollo.routing.CurveRange\x12-\n\tright_out\x18\x04 \x03(\x0b\x32\x1a.apollo.routing.CurveRange\x12\x0c\n\x04\x63ost\x18\x05 \x01(\x01\x12*\n\rcentral_curve\x18\x06 \x01(\x0b\x32\x13.apollo.hdmap.Curve\x12\x18\n\nis_virtual\x18\x07 \x01(\x08:\x04true\x12\x0f\n\x07road_id\x18\x08 \x01(\t\"\xad\x01\n\x04\x45\x64ge\x12\x14\n\x0c\x66rom_lane_id\x18\x01 \x01(\t\x12\x12\n\nto_lane_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ost\x18\x03 \x01(\x01\x12:\n\x0e\x64irection_type\x18\x04 \x01(\x0e\x32\".apollo.routing.Edge.DirectionType\"1\n\rDirectionType\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\"~\n\x05Graph\x12\x15\n\rhdmap_version\x18\x01 \x01(\t\x12\x16\n\x0ehdmap_district\x18\x02 \x01(\t\x12\"\n\x04node\x18\x03 \x03(\x0b\x32\x14.apollo.routing.Node\x12\"\n\x04\x65\x64ge\x18\x04 \x03(\x0b\x32\x14.apollo.routing.Edge'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])



_EDGE_DIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='DirectionType',
  full_name='apollo.routing.Edge.DirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=580,
  serialized_end=629,
)
_sym_db.RegisterEnumDescriptor(_EDGE_DIRECTIONTYPE)


_CURVEPOINT = _descriptor.Descriptor(
  name='CurvePoint',
  full_name='apollo.routing.CurvePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.routing.CurvePoint.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=119,
)


_CURVERANGE = _descriptor.Descriptor(
  name='CurveRange',
  full_name='apollo.routing.CurveRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='apollo.routing.CurveRange.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='apollo.routing.CurveRange.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=217,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='apollo.routing.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.routing.Node.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.routing.Node.length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_out', full_name='apollo.routing.Node.left_out', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_out', full_name='apollo.routing.Node.right_out', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='apollo.routing.Node.cost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='apollo.routing.Node.central_curve', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual', full_name='apollo.routing.Node.is_virtual', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_id', full_name='apollo.routing.Node.road_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=453,
)


_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='apollo.routing.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_lane_id', full_name='apollo.routing.Edge.from_lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_lane_id', full_name='apollo.routing.Edge.to_lane_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='apollo.routing.Edge.cost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction_type', full_name='apollo.routing.Edge.direction_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EDGE_DIRECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=629,
)


_GRAPH = _descriptor.Descriptor(
  name='Graph',
  full_name='apollo.routing.Graph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hdmap_version', full_name='apollo.routing.Graph.hdmap_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdmap_district', full_name='apollo.routing.Graph.hdmap_district', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='apollo.routing.Graph.node', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edge', full_name='apollo.routing.Graph.edge', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=757,
)

_CURVERANGE.fields_by_name['start'].message_type = _CURVEPOINT
_CURVERANGE.fields_by_name['end'].message_type = _CURVEPOINT
_NODE.fields_by_name['left_out'].message_type = _CURVERANGE
_NODE.fields_by_name['right_out'].message_type = _CURVERANGE
_NODE.fields_by_name['central_curve'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_EDGE.fields_by_name['direction_type'].enum_type = _EDGE_DIRECTIONTYPE
_EDGE_DIRECTIONTYPE.containing_type = _EDGE
_GRAPH.fields_by_name['node'].message_type = _NODE
_GRAPH.fields_by_name['edge'].message_type = _EDGE
DESCRIPTOR.message_types_by_name['CurvePoint'] = _CURVEPOINT
DESCRIPTOR.message_types_by_name['CurveRange'] = _CURVERANGE
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE
DESCRIPTOR.message_types_by_name['Graph'] = _GRAPH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CurvePoint = _reflection.GeneratedProtocolMessageType('CurvePoint', (_message.Message,), {
  'DESCRIPTOR' : _CURVEPOINT,
  '__module__' : 'modules.routing.proto.topo_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.CurvePoint)
  })
_sym_db.RegisterMessage(CurvePoint)

CurveRange = _reflection.GeneratedProtocolMessageType('CurveRange', (_message.Message,), {
  'DESCRIPTOR' : _CURVERANGE,
  '__module__' : 'modules.routing.proto.topo_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.CurveRange)
  })
_sym_db.RegisterMessage(CurveRange)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'modules.routing.proto.topo_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Node)
  })
_sym_db.RegisterMessage(Node)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), {
  'DESCRIPTOR' : _EDGE,
  '__module__' : 'modules.routing.proto.topo_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Edge)
  })
_sym_db.RegisterMessage(Edge)

Graph = _reflection.GeneratedProtocolMessageType('Graph', (_message.Message,), {
  'DESCRIPTOR' : _GRAPH,
  '__module__' : 'modules.routing.proto.topo_graph_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Graph)
  })
_sym_db.RegisterMessage(Graph)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/point_cloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/point_cloud.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/dreamview/proto/point_cloud.proto\x12\x10\x61pollo.dreamview\"\x1d\n\nPointCloud\x12\x0f\n\x03num\x18\x01 \x03(\x02\x42\x02\x10\x01'
)




_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='apollo.dreamview.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='apollo.dreamview.PointCloud.num', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=92,
)

DESCRIPTOR.message_types_by_name['PointCloud'] = _POINTCLOUD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUD,
  '__module__' : 'modules.dreamview.proto.point_cloud_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.PointCloud)
  })
_sym_db.RegisterMessage(PointCloud)


_POINTCLOUD.fields_by_name['num']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/data/tools/smart_recorder/proto/smart_recorder_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/data/tools/smart_recorder/proto/smart_recorder_status.proto',
  package='apollo.data',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCmodules/data/tools/smart_recorder/proto/smart_recorder_status.proto\x12\x0b\x61pollo.data\x1a!modules/common/proto/header.proto\"\x89\x01\n\x13SmartRecorderStatus\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x34\n\x0frecording_state\x18\x02 \x01(\x0e\x32\x1b.apollo.data.RecordingState\x12\x15\n\rstate_message\x18\x03 \x01(\t*=\n\x0eRecordingState\x12\x0b\n\x07STOPPED\x10\x00\x12\r\n\tRECORDING\x10\x01\x12\x0f\n\x0bTERMINATING\x10\x02'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_RECORDINGSTATE = _descriptor.EnumDescriptor(
  name='RecordingState',
  full_name='apollo.data.RecordingState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECORDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERMINATING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=259,
  serialized_end=320,
)
_sym_db.RegisterEnumDescriptor(_RECORDINGSTATE)

RecordingState = enum_type_wrapper.EnumTypeWrapper(_RECORDINGSTATE)
STOPPED = 0
RECORDING = 1
TERMINATING = 2



_SMARTRECORDERSTATUS = _descriptor.Descriptor(
  name='SmartRecorderStatus',
  full_name='apollo.data.SmartRecorderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.data.SmartRecorderStatus.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recording_state', full_name='apollo.data.SmartRecorderStatus.recording_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_message', full_name='apollo.data.SmartRecorderStatus.state_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=257,
)

_SMARTRECORDERSTATUS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_SMARTRECORDERSTATUS.fields_by_name['recording_state'].enum_type = _RECORDINGSTATE
DESCRIPTOR.message_types_by_name['SmartRecorderStatus'] = _SMARTRECORDERSTATUS
DESCRIPTOR.enum_types_by_name['RecordingState'] = _RECORDINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SmartRecorderStatus = _reflection.GeneratedProtocolMessageType('SmartRecorderStatus', (_message.Message,), {
  'DESCRIPTOR' : _SMARTRECORDERSTATUS,
  '__module__' : 'modules.data.tools.smart_recorder.proto.smart_recorder_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.SmartRecorderStatus)
  })
_sym_db.RegisterMessage(SmartRecorderStatus)


# @@protoc_insertion_point(module_scope)
